@@ -13,8 +13,8 @@ from .config.labels import DEFAULT_LABELS
 from .config.dummy_values import DEFAULT_DUMMY_VALUES
 
 __version__ = "1.0.0"
-__author__ = "SecretStuff Team"
-__email__ = "info@secretstuff.com"
+__author__ = "axondendrite", "Aksman"
+__email__ = "amandogra2016@gmail.com", "akshatmanihar580@gmail.com"
 
 __all__ = [
     "PIIIdentifier",
